..
    This file describes user-visible changes between the versions.

    subsections could include these headings (in this order), omit if no content

    Notice
    Breaking Changes
    New Features
    Enhancements
    Fixes
    Maintenance
    Deprecations
    Known Problems
    New Contributors

Change History
##############

History of changes in the *gemviz* project.
Project `milestones <https://github.com/BCDA-APS/gemviz/milestones>`_
describe future plans.

..
   1.7.10
   ******

   Release expected by 2025-12-05.

   Fixes
   -------------

   * BUG 'dt_cycle_ends' in apstools.devices.aps_cycle.ApsCycleDM


1.0.0
******

Released 2026-01-15

Initial public release.
